==> qt-creator-opensource-src-4.6.2.zip: qt-creator-opensource-src-4.6.2/src/plugins/cpptools/followsymbolinterface.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "cpptools_global.h"
#include "cursorineditor.h"

#include <cplusplus/CppDocument.h>

#include <texteditor/texteditor.h>

namespace CppTools {

class SymbolFinder;

class CPPTOOLS_EXPORT FollowSymbolInterface
{
public:
    using Link = Utils::Link;

    virtual ~FollowSymbolInterface() {}
    virtual Link findLink(const CursorInEditor &data,
                          bool resolveTarget,
                          const CPlusPlus::Snapshot &snapshot,
                          const CPlusPlus::Document::Ptr &documentFromSemanticInfo,
                          SymbolFinder *symbolFinder,
                          bool inNextSplit) = 0;
};

} // namespace CppTools

==> qt-creator-opensource-src-5.0.2.zip: qt-creator-opensource-src-5.0.2/src/plugins/cpptools/followsymbolinterface.h <==
/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "cpptools_global.h"
#include "cursorineditor.h"

#include <cplusplus/CppDocument.h>

#include <texteditor/texteditor.h>

namespace CppTools {

class SymbolFinder;

class CPPTOOLS_EXPORT FollowSymbolInterface
{
public:
    using Link = Utils::Link;

    virtual ~FollowSymbolInterface() = default;
    virtual void findLink(const CursorInEditor &data,
                          Utils::ProcessLinkCallback &&processLinkCallback,
                          bool resolveTarget,
                          const CPlusPlus::Snapshot &snapshot,
                          const CPlusPlus::Document::Ptr &documentFromSemanticInfo,
                          SymbolFinder *symbolFinder,
                          bool inNextSplit) = 0;
    virtual void switchDeclDef(const CursorInEditor &data,
                               Utils::ProcessLinkCallback &&processLinkCallback,
                               const CPlusPlus::Snapshot &snapshot,
                               const CPlusPlus::Document::Ptr &documentFromSemanticInfo,
                               SymbolFinder *symbolFinder) = 0;
};

} // namespace CppTools
